@@ -25,6 +25,7 @@
 #include <QLibraryInfo>
 #include <QPluginLoader>
 #include <QProcess>
+#include <QStandardPaths>
 #include <QStringList>
 #include <QTranslator>
 #ifdef Q_OS_WIN
@@ -64,7 +65,7 @@ IaitoApplication::IaitoApplication(int &argc, char **argv)
 {
     // Setup application information
     setApplicationVersion(IAITO_VERSION_FULL);
-#ifndef Q_OS_MACX
+#ifndef Q_OS_MACOS
     setWindowIcon(QIcon(":/img/iaito.svg"));
 #endif
 #if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
@@ -142,6 +143,38 @@ IaitoApplication::IaitoApplication(int &argc, char **argv)
     qputenv("R_ALT_SRC_DIR", "1");
 #endif
 
+#ifdef MACOS_R2_BUNDLED
+    {
+        auto appdir = QDir(QCoreApplication::applicationDirPath()); // Contents/MacOS
+        appdir.cdUp();                                              // Contents
+
+        auto r2prefix = appdir;           // Contents
+        r2prefix.cd("Resources/radare2"); // Contents/Resources/radare2
+        qputenv("R2_PREFIX", r2prefix.absolutePath().toLocal8Bit());
+
+        auto r2bin = appdir; // Contents
+        r2bin.cd("Helpers"); // Contents/Helpers
+        auto paths = QStringList(QString::fromLocal8Bit(qgetenv("PATH")));
+        paths.prepend(r2bin.absolutePath());
+        qputenv("PATH", paths.join(QLatin1Char(':')).toLocal8Bit());
+
+        // auto sleighHome = appdir; // Contents
+        // sleighHome.cd("PlugIns/radare2/r2ghidra_sleigh"); // Contents/PlugIns/radare2/r2ghidra_sleigh
+        // qputenv("SLEIGHHOME", sleighHome.absolutePath().toLocal8Bit());
+
+        // Allow bundled radare2 and its plugins to save its data inside iaito app folders
+        qputenv(
+            "XDG_CACHE_HOME",
+            QStandardPaths::writableLocation(QStandardPaths::CacheLocation).toLocal8Bit());
+        qputenv(
+            "XDG_CONFIG_HOME",
+            QStandardPaths::writableLocation(QStandardPaths::AppConfigLocation).toLocal8Bit());
+        qputenv(
+            "XDG_DATA_HOME",
+            QStandardPaths::writableLocation(QStandardPaths::AppDataLocation).toLocal8Bit());
+    }
+#endif
+
     Core()->initialize(clOptions.enableR2Plugins);
     Core()->setSettings();
     Config()->loadInitial();
@@ -193,8 +226,7 @@ IaitoApplication::IaitoApplication(int &argc, char **argv)
         // check if this is the first execution of Iaito in this computer
         // Note: the execution after the preferences been reset, will be
         // considered as first-execution
-        if (Config()->isFirstExecution()) {
-            // TODO: add cmdline flag to show the welcome dialog
+        if (clOptions.showWelcomeDialog || Config()->isFirstExecution()) {
             mainWindow->displayWelcomeDialog();
         }
         mainWindow->displayNewFileDialog();
@@ -219,22 +251,6 @@ IaitoApplication::IaitoApplication(int &argc, char **argv)
     }
 #endif
 
-#ifdef Q_OS_MACOS
-    {
-        auto r2prefix = QDir(QCoreApplication::applicationDirPath()); // Contents/MacOS
-        r2prefix.cdUp(); // Contents
-        r2prefix.cd("Resources/r2"); // Contents/Resources/r2
-
-        auto sleighHome = r2prefix;
-        sleighHome.cd("share/radare2/plugins/r2ghidra_sleigh"); // Contents/Resources/r2/share/radare2/plugins/r2ghidra_sleigh
-        Core()->setConfig("r2ghidra.sleighhome", sleighHome.absolutePath());
-
-        auto r2decHome = r2prefix;
-        r2decHome.cd("share/radare2/plugins/r2dec-js"); // Contents/Resources/r2/share/radare2/plugins/r2dec-js
-        qputenv("R2DEC_HOME", r2decHome.absolutePath().toLocal8Bit());
-    }
-#endif
-
 #ifdef IAITO_APPVEYOR_R2DEC
     qputenv("R2DEC_HOME", "lib\\plugins\\r2dec-js");
 #endif
@@ -325,9 +341,9 @@ bool IaitoApplication::loadTranslations()
             QTranslator *trQtBase = new QTranslator;
             QTranslator *trQt = new QTranslator;
 
-            const QStringList &cutterTrPaths = Iaito::getTranslationsDirectories();
+            const QStringList &iaitoTrPaths = Iaito::getTranslationsDirectories();
 
-            for (const auto &trPath : cutterTrPaths) {
+            for (const auto &trPath : iaitoTrPaths) {
                 if (trIaito
                     && trIaito->load(it, QLatin1String("iaito"), QLatin1String("_"), trPath)) {
                     installTranslator(trIaito);
@@ -428,6 +444,9 @@ bool IaitoApplication::parseCommandLineOptions()
     QCommandLineOption disableR2Plugins("no-r2-plugins", QObject::tr("Do not load radare2 plugins"));
     cmd_parser.addOption(disableR2Plugins);
 
+    QCommandLineOption welcomeOption("welcome", QObject::tr("Show welcome dialog."));
+    cmd_parser.addOption(welcomeOption);
+
     cmd_parser.process(*this);
 
     IaitoCommandLineOptions opts;
@@ -522,6 +541,10 @@ bool IaitoApplication::parseCommandLineOptions()
         opts.enableR2Plugins = false;
     }
 
+    if (cmd_parser.isSet(welcomeOption)) {
+        opts.showWelcomeDialog = true;
+    }
+
     this->clOptions = opts;
     return true;
 }
