@@ -20,13 +20,21 @@ R2Task::~R2Task()
     r_core_task_decref(task);
 }
 
-void R2Task::taskFinishedCallback(void *user, char *)
+void R2Task::taskFinishedCallback(void *user, char *res)
 {
-    reinterpret_cast<R2Task *>(user)->taskFinished();
+    reinterpret_cast<R2Task *>(user)->taskFinished(res);
 }
 
-void R2Task::taskFinished()
+void R2Task::taskFinished(char *res)
 {
+    // Copy the result into resultRaw so it remains valid after r2 frees its
+    // internal buffer. Doing this here (in the r2 task callback) ensures we
+    // capture the output before it can be destroyed.
+    if (res) {
+        resultRaw = QByteArray(res);
+    } else {
+        resultRaw.clear();
+    }
     emit finished();
 }
 
@@ -51,14 +59,20 @@ void R2Task::joinTask()
 
 QString R2Task::getResult()
 {
+    if (!resultRaw.isEmpty()) {
+        return QString::fromUtf8(resultRaw.constData());
+    }
     if (task == nullptr) {
         return QString("");
     }
-    return QString::fromUtf8(task->res);
+    return QString::fromUtf8(task->res ? task->res : "");
 }
 
 QJsonDocument R2Task::getResultJson()
 {
+    if (!resultRaw.isEmpty()) {
+        return Core()->parseJson(resultRaw.constData(), task ? task->cmd : nullptr);
+    }
     if (task == nullptr) {
         return QJsonDocument();
     }
@@ -67,5 +81,8 @@ QJsonDocument R2Task::getResultJson()
 
 const char *R2Task::getResultRaw()
 {
+    if (!resultRaw.isEmpty()) {
+        return resultRaw.constData();
+    }
     return task != nullptr ? task->res : nullptr;
 }
