@@ -103,15 +103,11 @@ InitialOptionsDialog::InitialOptionsDialog(MainWindow *main)
 
     updatePDBLayout();
 
-    connect(ui->pdbCheckBox, &QCheckBox::stateChanged, this, &InitialOptionsDialog::updatePDBLayout);
+    connect(ui->pdbCheckBox, &QCheckBox::toggled, this, [this](bool) { updatePDBLayout(); });
 
     updateScriptLayout();
 
-    connect(
-        ui->scriptCheckBox,
-        &QCheckBox::stateChanged,
-        this,
-        &InitialOptionsDialog::updateScriptLayout);
+    connect(ui->scriptCheckBox, &QCheckBox::toggled, this, [this](bool) { updateScriptLayout(); });
 
     connect(ui->cancelButton, &QPushButton::clicked, this, &InitialOptionsDialog::reject);
 
@@ -162,14 +158,16 @@ void InitialOptionsDialog::loadOptions(const InitialOptions &options)
         analLevel = 0;
     } else if (options.analCmd.first().command == "aa") {
         analLevel = 1;
-    } else if (options.analCmd.first().command == "aaa") {
+    } else if (options.analCmd.first().command == "aac") {
         analLevel = 2;
-    } else if (options.analCmd.first().command == "aaaa") {
+    } else if (options.analCmd.first().command == "aaa") {
         analLevel = 3;
-    } else if (options.analCmd.first().command == "aaaaa") {
+    } else if (options.analCmd.first().command == "aaaa") {
         analLevel = 4;
-    } else {
+    } else if (options.analCmd.first().command == "aaaaa") {
         analLevel = 5;
+    } else {
+        analLevel = 6;
         AnalysisCommands item;
         QList<QString> commands = getAnalysisCommands(options);
         foreach (item, analysisCommands) {
@@ -207,7 +205,7 @@ void InitialOptionsDialog::loadOptions(const InitialOptions &options)
 
 void InitialOptionsDialog::setTooltipWithConfigHelp(QWidget *w, const char *config)
 {
-    w->setToolTip(QString("%1 (%2)").arg(core->getConfigDescription(config)).arg(config));
+    w->setToolTip(QStringLiteral("%1 (%2)").arg(core->getConfigDescription(config)).arg(config));
 }
 
 QString InitialOptionsDialog::getSelectedArch() const
@@ -256,7 +254,7 @@ QString InitialOptionsDialog::getSelectedOS() const
 QList<CommandDescription> InitialOptionsDialog::getSelectedAdvancedAnalCmds() const
 {
     QList<CommandDescription> advanced = QList<CommandDescription>();
-    if (ui->analSlider->value() == 3) {
+    if (ui->analSlider->value() == 7) {
         AnalysisCommands item;
         foreach (item, analysisCommands) {
             if (item.checkbox->isChecked()) {
@@ -283,8 +281,8 @@ void InitialOptionsDialog::setupAndStartAnalysis(
         options.binLoadAddr = Core()->math(ui->entry_loadOffset->text());
     }
 
-    options.mapAddr = Core()->math(
-        ui->entry_mapOffset->text()); // Where to map the file once loaded (-m)
+    // Where to map the file once loaded (-m)
+    options.mapAddr = Core()->math(ui->entry_mapOffset->text());
     options.arch = getSelectedArch();
     options.cpu = getSelectedCPU();
     options.bits = getSelectedBits();
@@ -310,19 +308,25 @@ void InitialOptionsDialog::setupAndStartAnalysis(
 
     int level = ui->analSlider->value();
     switch (level) {
+    case 0:
+        options.analCmd = {};
+        break;
     case 1:
         options.analCmd = {{"aa", "Auto analysis"}};
         break;
     case 2:
-        options.analCmd = {{"aaa", "Advanced Auto analysis"}};
+        options.analCmd = {{"aac", "Analyse function calls"}};
         break;
     case 3:
-        options.analCmd = {{"aaaa", "Experimental analysis"}};
+        options.analCmd = {{"aaa", "Advanced Auto analysis"}};
         break;
     case 4:
-        options.analCmd = {{"aaaaa", "Unstable analysis"}};
+        options.analCmd = {{"aaaa", "Experimental analysis"}};
         break;
     case 5:
+        options.analCmd = {{"aaaaa", "Unstable analysis"}};
+        break;
+    case 6:
         options.analCmd = getSelectedAdvancedAnalCmds();
         break;
     default:
@@ -365,6 +369,9 @@ void InitialOptionsDialog::setupAndStartAnalysis(
         QMessageBox::warning(this, tr("Error"), tr("Please select a file"));
         return;
     }
+    if (options.filename.startsWith("malloc:")) {
+        options.loadBinInfo = false;
+    }
     // Do not reload the file if already loaded
     // QJsonArray openedFiles = Core()->getOpenedFiles();
     // if (true)  { // !openedFiles.size() && options.filename.length()) {
@@ -416,17 +423,13 @@ void InitialOptionsDialog::setupAndStartAnalysis(
         Core()->loadScript(options.script);
     }
 
+    const bool boi = Core()->getConfigb("esil.breakoninvalid");
+    Config()->setConfig("esil.breakoninvalid", false);
     if (!options.analCmd.empty()) {
-        //       log(tr("Executing analysis..."));
         for (const CommandDescription &cmd : options.analCmd) {
-            // log(cmd.description);
-            //  log(cmd.command + " : " + cmd.description);
-            // use cmd instead of cmdRaw because commands can be unexpected
             Core()->cmd(cmd.command);
         }
-        // log(tr("Analysis complete!"));
-    } else {
-        //        log(tr("Skipping Analysis."));
+        Core()->setConfig("esil.breakoninvalid", boi);
     }
 #endif
     main->finalizeOpen();
@@ -452,11 +455,15 @@ QString InitialOptionsDialog::analysisDescription(int level)
     case 1:
         return tr("Auto-Analysis (aa)");
     case 2:
-        return tr("Advanced Analysis (aaa)");
+        return tr("Call-Analysis (aac)");
     case 3:
-        return tr("Experimental Analysis (aaaa)");
+        return tr("Advanced Analysis (aaa)");
     case 4:
+        return tr("Experimental Analysis (aaaa)");
+    case 5:
         return tr("Cutting Edge Analysis (aaaaa)");
+    case 6:
+        return tr("Custom Analysis Steps");
     default:
         return tr("Unknown");
     }
@@ -464,14 +471,15 @@ QString InitialOptionsDialog::analysisDescription(int level)
 
 void InitialOptionsDialog::on_analSlider_valueChanged(int value)
 {
-    ui->analDescription->setText(tr("Level") + QString(": %1").arg(analysisDescription(value)));
+    ui->analDescription->setText(
+        tr("Level") + QStringLiteral(": %1").arg(analysisDescription(value)));
     if (value == 0) {
         ui->analCheckBox->setChecked(false);
         ui->analCheckBox->setText(tr("Analysis: Disabled"));
     } else {
         ui->analCheckBox->setChecked(true);
-        ui->analCheckBox->setText(tr("Analysis: Enabled"));
-        if (value == 5) {
+        ui->analCheckBox->setText(tr("Run Analysis"));
+        if (value == 6) {
             ui->analoptionsFrame->setVisible(true);
             ui->advancedAnlysisLine->setVisible(true);
         } else {
