@@ -33,7 +33,7 @@ private slots:
     void on_maxColsSpinBox_valueChanged(int value);
     void on_graphOffsetCheckBox_toggled(bool checked);
 
-    void checkTransparentStateChanged(int checked);
+    void checkTransparentStateChanged(bool checked);
     void bitmapGraphScaleValueChanged(double value);
     void checkGraphBlockEntryOffsetChanged(bool checked);
     void layoutSpacingChanged();
