@@ -88,6 +88,9 @@ DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *main
         SLOT(on_actionCopyAddr_triggered()),
         getCopyAddressSequence());
     addAction(&actionCopyAddr);
+    // Copy raw bytes of selected instructions
+    initAction(&actionCopyBytes, tr("Copy bytes"), SLOT(on_actionCopyBytes_triggered()));
+    addAction(&actionCopyBytes);
 
     initAction(&showInSubmenu, tr("Show in"), nullptr);
     addAction(&showInSubmenu);
@@ -192,6 +195,13 @@ DisassemblyContextMenu::DisassemblyContextMenu(QWidget *parent, MainWindow *main
         tr("Show Options"),
         SLOT(on_actionDisplayOptions_triggered()),
         getDisplayOptionsSequence());
+    // Add "Relative to" submenu to select asm.addr.relto values at runtime
+    relativeToMenu = addMenu(tr("Relative to"));
+    connect(
+        relativeToMenu,
+        &QMenu::triggered,
+        this,
+        &DisassemblyContextMenu::on_actionRelativeTo_triggered);
 
     addSeparator();
 
@@ -601,6 +611,19 @@ void DisassemblyContextMenu::aboutToShowSlot()
     bool immBase = keys.contains("val") || keys.contains("ptr");
     setBaseMenu->menuAction()->setVisible(immBase);
     setBitsMenu->menuAction()->setVisible(true);
+    // Populate "Relative to" submenu with asm.addr.relto options
+    relativeToMenu->clear();
+    // Query possible values via radare2 config
+    QStringList relVals = Core()->cmdList("e asm.addr.relto=?");
+    for (const QString &val : relVals) {
+        if (val.isEmpty()) {
+            continue;
+        }
+        QAction *act = relativeToMenu->addAction(val);
+        act->setData(val);
+    }
+    // Show submenu only if options are available
+    relativeToMenu->menuAction()->setVisible(!relVals.isEmpty());
 
     // Create structure offset menu if it makes sense
     QString memBaseReg; // Base register
@@ -661,6 +684,7 @@ void DisassemblyContextMenu::aboutToShowSlot()
     }
 
     actionCopy.setVisible(canCopy);
+    actionCopyBytes.setVisible(canCopy);
     copySeparator->setVisible(canCopy);
 
     // Handle renaming of variable, function, flag, ...
@@ -884,6 +908,11 @@ void DisassemblyContextMenu::on_actionCopyAddr_triggered()
     QClipboard *clipboard = QApplication::clipboard();
     clipboard->setText(RAddressString(offset));
 }
+// Slot triggered by context menu to request copying raw bytes of the selected instructions
+void DisassemblyContextMenu::on_actionCopyBytes_triggered()
+{
+    emit copyBytes();
+}
 
 void DisassemblyContextMenu::on_actionAddBreakpoint_triggered()
 {
@@ -944,7 +973,7 @@ void DisassemblyContextMenu::on_actionEditAnnotation_triggered()
     QString os = Core()->cmdRaw("anos");
     QString *s = openTextEditDialog(os, this);
     if (s != nullptr) {
-        Core()->cmdRaw(QString("ano=base64:%1").arg(QString(s->toLocal8Bit().toBase64())));
+        Core()->cmdRaw(QStringLiteral("ano=base64:%1").arg(QString(s->toLocal8Bit().toBase64())));
         this->mainWindow->refreshAll();
     }
 }
@@ -968,8 +997,9 @@ void DisassemblyContextMenu::on_actionRename_triggered()
     }
     case RENAME_FLAG:
     case RENAME_ADD_FLAG: {
-        FlagDialog dialog(doRenameInfo.addr, this->mainWindow);
-        ok = dialog.exec();
+        // defaultSize unused for existing flags, use 1
+        FlagDialog dialog(doRenameInfo.addr, 1, this->mainWindow);
+        ok = (dialog.exec() == QDialog::Accepted);
     } break;
     case RENAME_LOCAL: {
         RAnalFunction *fcn = Core()->functionIn(offset);
@@ -1133,6 +1163,14 @@ void DisassemblyContextMenu::on_actionLinkType_triggered()
     }
     dialog.exec();
 }
+// Slot to handle selection of "Relative to" values
+void DisassemblyContextMenu::on_actionRelativeTo_triggered(QAction *action)
+{
+    const QString val = action->data().toString();
+    // Set the asm.addr.relto configuration and refresh disassembly view
+    Core()->setConfig("asm.addr.relto", val);
+    Core()->triggerAsmOptionsChanged();
+}
 
 void DisassemblyContextMenu::on_actionDeleteComment_triggered()
 {
@@ -1167,7 +1205,11 @@ void DisassemblyContextMenu::on_actionEditFunction_triggered()
         QStringList callConList = Core()->cmdRaw("afcl").split("\n");
         callConList.removeLast();
         dialog.setCallConList(callConList);
+#if R2_VERSION_NUMBER >= 50909
+        dialog.setCallConSelected(fcn->callconv);
+#else
         dialog.setCallConSelected(fcn->cc);
+#endif
 
         if (dialog.exec()) {
             QString new_name = dialog.getNameText();
@@ -1195,7 +1237,7 @@ void DisassemblyContextMenu::setBits(int bits)
 void DisassemblyContextMenu::setColor(const char *color)
 {
     if (*color) {
-        Core()->cmd(QString("abc ") + QString(color));
+        Core()->cmd(QStringLiteral("abc ") + QString(color));
     } else {
         Core()->cmd("abc-");
     }
