@@ -2,11 +2,15 @@
 #include "common/Configuration.h"
 #include "common/Helpers.h"
 #include "common/SelectionHighlight.h"
+#include "common/ShortcutKeys.h"
 #include "common/TempConfig.h"
 #include "core/MainWindow.h"
+#include "dialogs/ShortcutKeysDialog.h"
 #include "menus/DisassemblyContextMenu.h"
 
+#include <algorithm>
 #include <QApplication>
+#include <QClipboard>
 #include <QJsonArray>
 #include <QJsonObject>
 #include <QPainter>
@@ -65,14 +69,14 @@ DisassemblyWidget::DisassemblyWidget(MainWindow *main)
 #endif
     mDisasScrollArea->viewport()->setLayout(layout);
     splitter->addWidget(mDisasScrollArea);
-    mDisasScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
     // Use stylesheet instead of QWidget::setFrameShape(QFrame::NoShape) to
     // avoid issues with dark and light interface themes
-    mDisasScrollArea->setStyleSheet("QAbstractScrollArea { border: 0px transparent black; }");
     mDisasTextEdit->setStyleSheet("QPlainTextEdit { border: 0px transparent black; }");
     mDisasTextEdit->setFocusProxy(this);
     mDisasTextEdit->setFocusPolicy(Qt::ClickFocus);
+    mDisasScrollArea->setStyleSheet("QAbstractScrollArea { border: 0px transparent black; }");
     mDisasScrollArea->setFocusProxy(this);
+    mDisasScrollArea->setVerticalScrollBarPolicy(Qt::ScrollBarPolicy::ScrollBarAlwaysOff);
     mDisasScrollArea->setFocusPolicy(Qt::ClickFocus);
 
     setFocusPolicy(Qt::ClickFocus);
@@ -81,8 +85,8 @@ DisassemblyWidget::DisassemblyWidget(MainWindow *main)
     connect(qApp, &QApplication::focusChanged, this, [this](QWidget *, QWidget *now) {
         QColor borderColor = this == now ? palette().color(QPalette::Highlight)
                                          : palette().color(QPalette::WindowText).darker();
-        widget()->setStyleSheet(QString("QSplitter { border: %1px solid %2 } \n"
-                                        "QSplitter:hover { border: %1px solid %3 } \n")
+        widget()->setStyleSheet(QStringLiteral("QSplitter { border: %1px solid %2 } \n"
+                                               "QSplitter:hover { border: %1px solid %3 } \n")
                                     .arg(devicePixelRatio())
                                     .arg(borderColor.name())
                                     .arg(palette().color(QPalette::Highlight).name()));
@@ -145,7 +149,7 @@ DisassemblyWidget::DisassemblyWidget(MainWindow *main)
         &DisassemblyWidget::updateMaxLines);
 
     connectCursorPositionChanged(false);
-    connect(mDisasTextEdit->verticalScrollBar(), &QScrollBar::valueChanged, this, [=](int value) {
+    connect(mDisasTextEdit->verticalScrollBar(), &QScrollBar::valueChanged, this, [this](int value) {
         if (value != 0) {
             mDisasTextEdit->verticalScrollBar()->setValue(0);
         }
@@ -170,6 +174,8 @@ DisassemblyWidget::DisassemblyWidget(MainWindow *main)
     refreshDisasm(seekable->getOffset());
 
     connect(mCtxMenu, &DisassemblyContextMenu::copy, mDisasTextEdit, &QPlainTextEdit::copy);
+    // Connect copyBytes signal to slot for copying raw instruction bytes
+    connect(mCtxMenu, &DisassemblyContextMenu::copyBytes, this, &DisassemblyWidget::copyBytes);
 
     mCtxMenu->addSeparator();
     mCtxMenu->addAction(&syncAction);
@@ -316,13 +322,13 @@ void DisassemblyWidget::refreshDisasm(RVA offset)
         cursor.setBlockFormat(regular);
     }
 
-    if (!lines.isEmpty()) {
+    if (lines.isEmpty()) {
+        bottomOffset = topOffset;
+    } else {
         bottomOffset = lines[qMin(lines.size(), maxLines) - 1].offset;
         if (bottomOffset < topOffset) {
             bottomOffset = RVA_MAX;
         }
-    } else {
-        bottomOffset = topOffset;
     }
 
     connectCursorPositionChanged(false);
@@ -664,6 +670,45 @@ void DisassemblyWidget::moveCursorRelative(bool up, bool page)
         }
     }
 }
+// Slot to handle copying raw bytes of selected instructions
+void DisassemblyWidget::copyBytes()
+{
+    QTextCursor cursor = mDisasTextEdit->textCursor();
+    if (!cursor.hasSelection()) {
+        return;
+    }
+    int selStart = cursor.selectionStart();
+    int selEnd = cursor.selectionEnd();
+    if (selEnd <= selStart) {
+        return;
+    }
+    // Adjust end position to fall within the last selected line
+    selEnd -= 1;
+    // Determine start and end offsets based on text blocks
+    QTextCursor startCursor = mDisasTextEdit->textCursor();
+    startCursor.setPosition(selStart);
+    QTextCursor endCursor = mDisasTextEdit->textCursor();
+    endCursor.setPosition(selEnd);
+    RVA startOffset = readDisassemblyOffset(startCursor);
+    RVA endOffset = readDisassemblyOffset(endCursor);
+    if (startOffset == RVA_INVALID || endOffset == RVA_INVALID) {
+        return;
+    }
+    if (startOffset > endOffset) {
+        std::swap(startOffset, endOffset);
+    }
+    // Get size of the last instruction
+    QJsonObject instObj
+        = Core()->cmdj(QStringLiteral("aoj @ %1").arg(endOffset)).array().first().toObject();
+    int instrSize = instObj.value("size").toInt(1);
+    // Compute byte count to copy
+    int count = int(endOffset - startOffset) + instrSize;
+    // Fetch bytes in hex format
+    QString bytesStr = Core()->cmdRawAt(QStringLiteral("p8 %1").arg(count), startOffset).trimmed();
+    // Copy to clipboard
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(bytesStr);
+}
 
 void DisassemblyWidget::jumpToOffsetUnderCursor(const QTextCursor &cursor)
 {
@@ -678,7 +723,12 @@ bool DisassemblyWidget::eventFilter(QObject *obj, QEvent *event)
         QMouseEvent *mouseEvent = static_cast<QMouseEvent *>(event);
 
         const QTextCursor &cursor = mDisasTextEdit->cursorForPosition(
-            QPoint(mouseEvent->x(), mouseEvent->y()));
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+            mouseEvent->position().toPoint()
+#else
+            QPoint(mouseEvent->x(), mouseEvent->y())
+#endif
+        );
         jumpToOffsetUnderCursor(cursor);
 
         return true;
@@ -719,11 +769,11 @@ bool DisassemblyWidget::eventFilter(QObject *obj, QEvent *event)
                     const QFont &fnt = Config()->getFont();
                     QFontMetrics fm{fnt};
 
-                    QString tooltip = QString("<html><div style=\"font-family: %1; "
-                                              "font-size: %2pt; white-space: nowrap;\"><div "
-                                              "style=\"margin-bottom: "
-                                              "10px;\"><strong>Disassembly "
-                                              "Preview</strong>:<br>%3<div>")
+                    QString tooltip = QStringLiteral("<html><div style=\"font-family: %1; "
+                                                     "font-size: %2pt; white-space: nowrap;\"><div "
+                                                     "style=\"margin-bottom: "
+                                                     "10px;\"><strong>Disassembly "
+                                                     "Preview</strong>:<br>%3<div>")
                                           .arg(fnt.family())
                                           .arg(qMax(6, fnt.pointSize() - 1))
                                           .arg(disasmPreview.join("<br>"));
@@ -740,6 +790,22 @@ bool DisassemblyWidget::eventFilter(QObject *obj, QEvent *event)
 
 void DisassemblyWidget::keyPressEvent(QKeyEvent *event)
 {
+    // Handle Vim-like mark and jump
+    if (event->modifiers() == Qt::NoModifier && event->key() == Qt::Key_M) {
+        // Set mark at current offset
+        ShortcutKeysDialog dlg(ShortcutKeysDialog::SetMark, seekable->getOffset(), this);
+        dlg.exec();
+        return;
+    } else if (event->modifiers() == Qt::NoModifier && event->key() == Qt::Key_Apostrophe) {
+        // Jump to mark
+        ShortcutKeysDialog dlg(ShortcutKeysDialog::JumpTo, RVA_INVALID, this);
+        if (dlg.exec() == QDialog::Accepted) {
+            QChar key = dlg.selectedKey();
+            RVA addr = ShortcutKeys::instance()->getMark(key);
+            seekable->seek(addr);
+        }
+        return;
+    }
     if (event->key() == Qt::Key_Return) {
         const QTextCursor cursor = mDisasTextEdit->textCursor();
         jumpToOffsetUnderCursor(cursor);
@@ -799,9 +865,10 @@ void DisassemblyWidget::setupFonts()
 
 void DisassemblyWidget::setupColors()
 {
-    mDisasTextEdit->setStyleSheet(QString("QPlainTextEdit { background-color: %1; color: %2; }")
-                                      .arg(ConfigColor("gui.background").name())
-                                      .arg(ConfigColor("btext").name()));
+    mDisasTextEdit->setStyleSheet(
+        QStringLiteral("QPlainTextEdit { background-color: %1; color: %2; }")
+            .arg(ConfigColor("gui.background").name())
+            .arg(ConfigColor("btext").name()));
 }
 
 DisassemblyScrollArea::DisassemblyScrollArea(QWidget *parent)
