@@ -1,7 +1,15 @@
 #include "HexWidget.h"
 #include "Configuration.h"
 #include "Iaito.h"
+#include "common/ShortcutKeys.h"
+#include "dialogs/FlagDialog.h"
+#include "dialogs/ShortcutKeysDialog.h"
 #include "dialogs/WriteCommandsDialogs.h"
+#include <r_flag.h>
+#include <set>
+#include <QKeyEvent>
+#include <QList>
+#include <QStringList>
 
 #include <QActionGroup>
 #include <QApplication>
@@ -22,6 +30,83 @@
 #include <QWheelEvent>
 #include <QtEndian>
 
+// Draw background highlighting for flags over the hex or ascii area
+void HexWidget::drawFlagsBackground(QPainter &painter, bool ascii)
+{
+    // Skip if no flags defined at all
+    RFlag *rf = Core()->core()->flags;
+    if (!rf || r_flag_count(rf, NULL) == 0) {
+        return;
+    }
+    uint64_t startAddr = startAddress;
+    uint64_t lastAddr = lastVisibleAddr();
+    if (startAddr > lastAddr) {
+        return;
+    }
+    painter.save();
+    painter.setPen(Qt::NoPen);
+    // Track drawn flags to avoid duplicates
+    std::set<RFlagItem *> drawn;
+    for (uint64_t addr = startAddr; addr <= lastAddr; ++addr) {
+        // Get flag covering this offset
+#if R2_VERSION_NUMBER >= 50909
+        RFlagItem *fi = r_flag_get_in(rf, addr);
+#else
+        RFlagItem *fi = r_flag_get_i(rf, addr);
+#endif
+        if (!fi || drawn.count(fi)) {
+            continue;
+        }
+        drawn.insert(fi);
+        // Compute flag range
+#if R2_VERSION_NUMBER >= 50909
+        uint64_t start = fi->addr;
+        uint64_t end = fi->addr + fi->size - 1;
+        // Determine color
+        RFlagItemMeta *fim = r_flag_get_meta(rf, fi->id);
+        QColor bg = (fim && fim->color) ? QColor(QString::fromUtf8(fim->color)) : QColor(Qt::gray);
+        bg.setAlphaF(0.3);
+        painter.setBrush(bg);
+#else
+        uint64_t start = fi->offset;
+        uint64_t end = fi->offset + fi->size - 1;
+#endif
+        // Highlight the full flag region (clipped by rangePolygons)
+        auto polys = rangePolygons(start, end, ascii);
+        for (const auto &poly : polys) {
+            painter.drawPolygon(poly);
+        }
+    }
+    painter.restore();
+}
+// Draw the status bar displaying offset and fd command output
+void HexWidget::drawStatusBar(QPainter &painter)
+{
+    painter.save();
+    // Ignore any scroll translation
+    painter.resetTransform();
+
+    // Prepare text metrics and position
+    QFontMetrics fm = painter.fontMetrics();
+    int x = 2;
+    int y = viewport()->height() - 2;
+    int textWidth = fm.horizontalAdvance(statusBarText);
+    int textAscent = fm.ascent();
+    int textDescent = fm.descent();
+    int textHeight = textAscent + textDescent;
+    QRect bgRect(x, y - textAscent, textWidth, textHeight);
+
+    // Draw solid background behind status text
+    painter.setPen(Qt::NoPen);
+    painter.setBrush(backgroundColor);
+    painter.drawRect(bgRect);
+
+    // Draw status text on top
+    painter.setPen(defColor);
+    painter.drawText(x, y, statusBarText);
+    painter.restore();
+}
+
 static constexpr uint64_t MAX_COPY_SIZE = 128 * 1024 * 1024;
 static constexpr int MAX_LINE_WIDTH_PRESET = 32;
 static constexpr int MAX_LINE_WIDTH_BYTES = 128 * 1024;
@@ -59,7 +144,7 @@ HexWidget::HexWidget(QWidget *parent)
         QAction *action = new QAction(QString::number(i), this);
         action->setCheckable(true);
         action->setActionGroup(sizeActionGroup);
-        connect(action, &QAction::triggered, this, [=]() { setItemSize(i); });
+        connect(action, &QAction::triggered, this, [=, this]() { setItemSize(i); });
         actionsItemSize.append(action);
     }
     actionsItemSize.at(0)->setChecked(true);
@@ -77,7 +162,7 @@ HexWidget::HexWidget(QWidget *parent)
         QAction *action = new QAction(names.at(i), this);
         action->setCheckable(true);
         action->setActionGroup(formatActionGroup);
-        connect(action, &QAction::triggered, this, [=]() {
+        connect(action, &QAction::triggered, this, [=, this]() {
             setItemFormat(static_cast<ItemFormat>(i));
         });
         actionsItemFormat.append(action);
@@ -91,14 +176,14 @@ HexWidget::HexWidget(QWidget *parent)
         QAction *action = new QAction(QString::number(i), rowSizeMenu);
         action->setCheckable(true);
         action->setActionGroup(columnsActionGroup);
-        connect(action, &QAction::triggered, this, [=]() { setFixedLineSize(i); });
+        connect(action, &QAction::triggered, this, [=, this]() { setFixedLineSize(i); });
         rowSizeMenu->addAction(action);
     }
     rowSizeMenu->addSeparator();
     actionRowSizePowerOf2 = new QAction(tr("Power of 2"), this);
     actionRowSizePowerOf2->setCheckable(true);
     actionRowSizePowerOf2->setActionGroup(columnsActionGroup);
-    connect(actionRowSizePowerOf2, &QAction::triggered, this, [=]() {
+    connect(actionRowSizePowerOf2, &QAction::triggered, this, [this]() {
         setColumnMode(ColumnMode::PowerOf2);
     });
     rowSizeMenu->addAction(actionRowSizePowerOf2);
@@ -123,6 +208,11 @@ HexWidget::HexWidget(QWidget *parent)
     actionCopyAddress->setShortcut(Qt::CTRL | Qt::SHIFT | Qt::Key_C);
     connect(actionCopyAddress, &QAction::triggered, this, &HexWidget::copyAddress);
     addAction(actionCopyAddress);
+    // Action to copy selected bytes as a C string
+    actionCopyAsCString = new QAction(tr("Copy as C string"), this);
+    actionCopyAsCString->setShortcutContext(Qt::ShortcutContext::WidgetWithChildrenShortcut);
+    connect(actionCopyAsCString, &QAction::triggered, this, &HexWidget::copyAsCString);
+    addAction(actionCopyAsCString);
 
     actionSelectRange = new QAction(tr("Select range"), this);
     connect(actionSelectRange, &QAction::triggered, this, [this]() {
@@ -153,6 +243,54 @@ HexWidget::HexWidget(QWidget *parent)
     actionsWriteString.append(actionWrite64);
 
     actionsWriteOther.reserve(4);
+    // Setup numeric write actions (8,16,32,64 bit)
+    actionsWriteNumber.reserve(4);
+    struct NumAction
+    {
+        int bytes;
+        const char *text;
+    } numActions[] = {
+        {1, "Write 8-bit value..."},
+        {2, "Write 16-bit value..."},
+        {4, "Write 32-bit value..."},
+        {8, "Write 64-bit value..."},
+    };
+    for (auto &na : numActions) {
+        QAction *act = new QAction(tr(na.text), this);
+        connect(act, &QAction::triggered, this, [this, na] { writeNumber(na.bytes); });
+        actionsWriteNumber.append(act);
+    }
+
+    // Setup address width selection actions (32-bit vs 64-bit)
+    actionsAddressWidth.reserve(2);
+    QActionGroup *addrWidthGroup = new QActionGroup(this);
+    addrWidthGroup->setExclusive(true);
+    // 32-bit addresses (8 hex digits)
+    QAction *actionAddr32 = new QAction(tr("32-bit addresses"), this);
+    actionAddr32->setCheckable(true);
+    actionAddr32->setActionGroup(addrWidthGroup);
+    connect(actionAddr32, &QAction::triggered, this, [this]() {
+        addrCharLen = AddrWidth32;
+        updateMetrics();
+        refresh();
+    });
+    actionsAddressWidth.append(actionAddr32);
+    // 64-bit addresses (16 hex digits)
+    QAction *actionAddr64 = new QAction(tr("64-bit addresses"), this);
+    actionAddr64->setCheckable(true);
+    actionAddr64->setActionGroup(addrWidthGroup);
+    connect(actionAddr64, &QAction::triggered, this, [this]() {
+        addrCharLen = AddrWidth64;
+        updateMetrics();
+        refresh();
+    });
+    actionsAddressWidth.append(actionAddr64);
+    // Set default checked based on initial addrCharLen
+    if (addrCharLen == AddrWidth32) {
+        actionAddr32->setChecked(true);
+    } else {
+        actionAddr64->setChecked(true);
+    }
     QAction *actionWriteZeros = new QAction(tr("Write zeros"), this);
     connect(actionWriteZeros, &QAction::triggered, this, &HexWidget::w_writeZeros);
     actionsWriteOther.append(actionWriteZeros);
@@ -442,6 +580,7 @@ void HexWidget::paintEvent(QPaintEvent *event)
         return;
 
     drawCursor(painter, true);
+    // Status bar is now handled by QStatusBar widget in the parent
 }
 
 void HexWidget::updateWidth()
@@ -478,8 +617,12 @@ void HexWidget::mouseMoveEvent(QMouseEvent *event)
     auto mouseAddr = mousePosToAddr(pos).address;
 
     QString metaData = getFlagsAndComment(mouseAddr);
-    if (!metaData.isEmpty() && itemArea.contains(pos)) {
+    if (!metaData.isEmpty() && (itemArea.contains(pos) || asciiArea.contains(pos))) {
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+        QToolTip::showText(event->globalPosition().toPoint(), metaData.replace(",", ", "), this);
+#else
         QToolTip::showText(event->globalPos(), metaData.replace(",", ", "), this);
+#endif
     } else {
         QToolTip::hideText();
     }
@@ -567,6 +710,20 @@ void HexWidget::wheelEvent(QWheelEvent *event)
 
 void HexWidget::keyPressEvent(QKeyEvent *event)
 {
+    // Handle Vim-like mark and jump
+    if (event->modifiers() == Qt::NoModifier && event->key() == Qt::Key_M) {
+        ShortcutKeysDialog dlg(ShortcutKeysDialog::SetMark, cursor.address, this);
+        dlg.exec();
+        return;
+    } else if (event->modifiers() == Qt::NoModifier && event->key() == Qt::Key_Apostrophe) {
+        ShortcutKeysDialog dlg(ShortcutKeysDialog::JumpTo, RVA_INVALID, this);
+        if (dlg.exec() == QDialog::Accepted) {
+            QChar key = dlg.selectedKey();
+            RVA addr = ShortcutKeys::instance()->getMark(key);
+            seek(addr);
+        }
+        return;
+    }
     bool select = false;
     auto moveOrSelect =
         [event,
@@ -622,6 +779,7 @@ void HexWidget::contextMenuEvent(QContextMenuEvent *event)
 
     auto disableOutsideSelectionActions = [this](bool disable) {
         actionCopyAddress->setDisabled(disable);
+        actionCopyAsCString->setDisabled(disable);
     };
 
     QMenu *menu = new QMenu();
@@ -629,18 +787,58 @@ void HexWidget::contextMenuEvent(QContextMenuEvent *event)
     sizeMenu->addActions(actionsItemSize);
     QMenu *formatMenu = menu->addMenu(tr("Item format:"));
     formatMenu->addActions(actionsItemFormat);
+    // Address width submenu (32-bit vs 64-bit)
+    QMenu *addrWidthMenu = menu->addMenu(tr("Address width"));
+    addrWidthMenu->addActions(actionsAddressWidth);
     menu->addMenu(rowSizeMenu);
     menu->addAction(actionHexPairs);
     menu->addAction(actionItemBigEndian);
-    QMenu *writeMenu = menu->addMenu(tr("Edit"));
+    QMenu *writeMenu = menu->addMenu(tr("Insert"));
     writeMenu->addActions(actionsWriteString);
     writeMenu->addSeparator();
+    // Numeric value write actions
+    writeMenu->addActions(actionsWriteNumber);
+    writeMenu->addSeparator();
     writeMenu->addActions(actionsWriteOther);
     menu->addSeparator();
     menu->addAction(actionCopy);
+    menu->addAction(actionCopyAsCString);
     disableOutsideSelectionActions(mouseOutsideSelection);
     menu->addAction(actionCopyAddress);
     menu->addActions(this->actions());
+    // Flag handling: edit or add flag at clicked address
+    menu->addSeparator();
+    if ((itemArea.contains(pt) || asciiArea.contains(pt))) {
+        // Determine base address: if user right-clicked inside an existing selection,
+        // use the lowest selected address; otherwise use the clicked byte.
+        uint64_t mouseAddr = mousePosToAddr(pt).address;
+        bool usingSel = !selection.isEmpty() && !mouseOutsideSelection;
+        uint64_t flagAddr = usingSel ? selection.start() : mouseAddr;
+        ut64 defaultSize = usingSel ? selection.size() : 1;
+#if R2_VERSION_NUMBER >= 50909
+        RFlagItem *fi = r_flag_get_in(Core()->core()->flags, flagAddr);
+#else
+        RFlagItem *fi = r_flag_get_i(Core()->core()->flags, flagAddr);
+#endif
+        // Add flag action (always available), pre-filling size if selecting
+        QAction *addFlag = menu->addAction(tr("Add flag..."));
+        connect(addFlag, &QAction::triggered, this, [this, flagAddr, defaultSize]() {
+            FlagDialog dlg(flagAddr, defaultSize, this);
+            if (dlg.exec() == QDialog::Accepted) {
+                refresh();
+            }
+        });
+        // If a flag exists here, offer to edit it too
+        if (fi) {
+            QAction *editFlag = menu->addAction(tr("Edit flag..."));
+            connect(editFlag, &QAction::triggered, this, [this, flagAddr]() {
+                FlagDialog dlg(flagAddr, 1, this);
+                if (dlg.exec() == QDialog::Accepted) {
+                    refresh();
+                }
+            });
+        }
+    }
     menu->exec(mapToGlobal(pt));
     disableOutsideSelectionActions(false);
     menu->deleteLater();
@@ -674,11 +872,13 @@ void HexWidget::copy()
     QClipboard *clipboard = QApplication::clipboard();
     if (cursorOnAscii) {
         clipboard->setText(
-            Core()->cmdRawAt(QString("psx %1").arg(selection.size()), selection.start()).trimmed());
+            Core()
+                ->cmdRawAt(QStringLiteral("psx %1").arg(selection.size()), selection.start())
+                .trimmed());
     } else {
         clipboard->setText(Core()
                                ->cmdRawAt(
-                                   QString("p8 %1").arg(selection.size()),
+                                   QStringLiteral("p8 %1").arg(selection.size()),
                                    selection.start())
                                .trimmed()); // TODO: copy in the format shown
     }
@@ -703,6 +903,33 @@ void HexWidget::onRangeDialogAccepted()
     selectRange(rangeDialog.getStartAddress(), rangeDialog.getEndAddress());
 }
 
+void HexWidget::copyAsCString()
+{
+    if (selection.isEmpty() || selection.size() > MAX_COPY_SIZE) {
+        return;
+    }
+    uint64_t addr = selection.start();
+    size_t len = selection.size();
+    QByteArray data = Core()->ioRead(addr, int(len));
+    QString out;
+    out.reserve(len * 4 + 2);
+    out.append('"');
+    for (unsigned char c : data) {
+        if (c == '\\') {
+            out.append("\\\\");
+        } else if (c == '"') {
+            out.append("\\\"");
+        } else if (c >= 0x20 && c <= 0x7e) {
+            out.append(QChar(c));
+        } else {
+            out.append(QStringLiteral("\\x%1").arg((unsigned) c, 2, 16, QLatin1Char('0')).toUpper());
+        }
+    }
+    out.append('"');
+    QClipboard *clipboard = QApplication::clipboard();
+    clipboard->setText(out);
+}
+
 void HexWidget::w_writeString()
 {
     if (!ioModesController.prepareForWriting()) {
@@ -713,7 +940,7 @@ void HexWidget::w_writeString()
     d.setInputMode(QInputDialog::InputMode::TextInput);
     QString str = d.getText(this, tr("Write string"), tr("String:"), QLineEdit::Normal, "", &ok);
     if (ok && !str.isEmpty()) {
-        Core()->cmdRawAt(QString("w %1").arg(str), getLocationAddress());
+        Core()->cmdRawAt(QStringLiteral("w %1").arg(str), getLocationAddress());
         refresh();
     }
 }
@@ -730,7 +957,7 @@ void HexWidget::w_increaseDecrease()
     }
     QString mode = d.getMode() == IncrementDecrementDialog::Increase ? "+" : "-";
     Core()->cmdRawAt(
-        QString("w%1%2 %3")
+        QStringLiteral("w%1%2 %3")
             .arg(QString::number(d.getNBytes()))
             .arg(mode)
             .arg(QString::number(d.getValue())),
@@ -754,7 +981,7 @@ void HexWidget::w_writeZeros()
     QString str = QString::number(
         d.getInt(this, tr("Write zeros"), tr("Number of zeros:"), size, 1, 0x7FFFFFFF, 1, &ok));
     if (ok && !str.isEmpty()) {
-        Core()->cmdRawAt(QString("w0 %1").arg(str), getLocationAddress());
+        Core()->cmdRawAt(QStringLiteral("w0 %1").arg(str), getLocationAddress());
         refresh();
     }
 }
@@ -785,7 +1012,8 @@ void HexWidget::w_write64()
     }
 
     Core()->cmdRawAt(
-        QString("w6%1 %2").arg(mode).arg((mode == "e" ? str.toHex() : str).toStdString().c_str()),
+        QStringLiteral("w6%1 %2").arg(mode).arg(
+            (mode == "e" ? str.toHex() : str).toStdString().c_str()),
         getLocationAddress());
     refresh();
 }
@@ -805,7 +1033,7 @@ void HexWidget::w_writeRandom()
     QString nbytes = QString::number(
         d.getInt(this, tr("Write random"), tr("Number of bytes:"), size, 1, 0x7FFFFFFF, 1, &ok));
     if (ok && !nbytes.isEmpty()) {
-        Core()->cmdRawAt(QString("wr %1").arg(nbytes), getLocationAddress());
+        Core()->cmdRawAt(QStringLiteral("wr %1").arg(nbytes), getLocationAddress());
         refresh();
     }
 }
@@ -822,7 +1050,7 @@ void HexWidget::w_duplFromOffset()
     }
     RVA copyFrom = d.getOffset();
     QString nBytes = QString::number(d.getNBytes());
-    Core()->cmdRawAt(QString("wd %1 %2").arg(copyFrom).arg(nBytes), getLocationAddress());
+    Core()->cmdRawAt(QStringLiteral("wd %1 %2").arg(copyFrom).arg(nBytes), getLocationAddress());
     refresh();
 }
 
@@ -837,7 +1065,7 @@ void HexWidget::w_writePascalString()
     QString str
         = d.getText(this, tr("Write Pascal string"), tr("String:"), QLineEdit::Normal, "", &ok);
     if (ok && !str.isEmpty()) {
-        Core()->cmdRawAt(QString("ws %1").arg(str), getLocationAddress());
+        Core()->cmdRawAt(QStringLiteral("ws %1").arg(str), getLocationAddress());
         refresh();
     }
 }
@@ -853,7 +1081,7 @@ void HexWidget::w_writeWideString()
     QString str
         = d.getText(this, tr("Write wide string"), tr("String:"), QLineEdit::Normal, "", &ok);
     if (ok && !str.isEmpty()) {
-        Core()->cmdRawAt(QString("ww %1").arg(str), getLocationAddress());
+        Core()->cmdRawAt(QStringLiteral("ww %1").arg(str), getLocationAddress());
         refresh();
     }
 }
@@ -869,10 +1097,47 @@ void HexWidget::w_writeCString()
     QString str = d.getText(
         this, tr("Write zero-terminated string"), tr("String:"), QLineEdit::Normal, "", &ok);
     if (ok && !str.isEmpty()) {
-        Core()->cmdRawAt(QString("wz %1").arg(str), getLocationAddress());
+        Core()->cmdRawAt(QStringLiteral("wz %1").arg(str), getLocationAddress());
         refresh();
     }
 }
+// Prompt for a numeric expression and write it as byteCount-wide value at current location
+void HexWidget::writeNumber(int byteCount)
+{
+    if (!ioModesController.prepareForWriting()) {
+        return;
+    }
+    bool ok = false;
+    QString expr = QInputDialog::getText(
+        this,
+        tr("Write %1-bit value").arg(byteCount * 8),
+        tr("Expression (supports flags/math):"),
+        QLineEdit::Normal,
+        QString(),
+        &ok);
+    if (!ok || expr.isEmpty()) {
+        return;
+    }
+    ut64 value = Core()->math(expr);
+    ut64 uValue;
+    if (byteCount < 8) {
+        ut64 mask = (1ULL << (byteCount * 8)) - 1;
+        uValue = value & mask;
+    } else {
+        uValue = value;
+    }
+    QString hex = QString::number(uValue, 16).rightJustified(byteCount * 2, QLatin1Char('0'));
+    bool bigEndian = Core()->getConfigb("cfg.bigendian");
+    if (!bigEndian) {
+        QString rev;
+        for (int i = hex.length(); i > 0; i -= 2) {
+            rev += hex.mid(i - 2, 2);
+        }
+        hex = rev;
+    }
+    Core()->cmdRawAt(QStringLiteral("wx %1").arg(hex), getLocationAddress());
+    refresh();
+}
 
 void HexWidget::updateItemLength()
 {
@@ -992,7 +1257,7 @@ void HexWidget::drawAddrArea(QPainter &painter)
     painter.setPen(addrColor);
     for (int line = 0; line < visibleLines && offset <= data->maxIndex();
          ++line, strRect.translate(0, lineHeight), offset += itemRowByteLen()) {
-        addrString = QString("%1").arg(offset, addrCharLen, 16, QLatin1Char('0'));
+        addrString = QStringLiteral("%1").arg(offset, addrCharLen, 16, QLatin1Char('0'));
         if (showExAddr)
             addrString.prepend(hexPrefix);
         painter.drawText(strRect, Qt::AlignVCenter, addrString);
@@ -1010,6 +1275,8 @@ void HexWidget::drawItemArea(QPainter &painter)
     QColor itemColor;
     QString itemString;
 
+    // Draw flag-backed highlights before any selection
+    drawFlagsBackground(painter, false);
     fillSelectionBackground(painter);
 
     uint64_t itemAddr = startAddress;
@@ -1019,14 +1286,6 @@ void HexWidget::drawItemArea(QPainter &painter)
             for (int k = 0; k < itemGroupSize && itemAddr <= data->maxIndex();
                  ++k, itemAddr += itemByteLen) {
                 itemString = renderItem(itemAddr - startAddress, &itemColor);
-
-                if (!getFlagsAndComment(itemAddr).isEmpty()) {
-                    QColor markerColor(borderColor);
-                    markerColor.setAlphaF(0.5);
-                    const auto shape = rangePolygons(itemAddr, itemAddr, false)[0];
-                    painter.setPen(markerColor);
-                    painter.drawPolyline(shape);
-                }
                 if (selection.contains(itemAddr) && !cursorOnAscii) {
                     itemColor = palette().highlightedText().color();
                 }
@@ -1057,6 +1316,8 @@ void HexWidget::drawAsciiArea(QPainter &painter)
 {
     QRectF charRect(asciiArea.topLeft(), QSizeF(charWidth, lineHeight));
 
+    // Draw flag-backed highlights before any selection in ASCII area
+    drawFlagsBackground(painter, true);
     fillSelectionBackground(painter, true);
 
     uint64_t address = startAddress;
@@ -1182,7 +1443,7 @@ void HexWidget::updateMetrics()
     lineHeight = fontMetrics.height();
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     // not implemented Qt::SHIFT doesnt exist
-    charWidth = 10;
+    charWidth = 9;
 #else
     charWidth = fontMetrics.width(QLatin1Char('F'));
 #endif
@@ -1197,7 +1458,6 @@ void HexWidget::updateMetrics()
     cursor.screenPos.setWidth(cursorWidth);
     if (cursorOnAscii) {
         cursor.screenPos.moveTopLeft(asciiArea.topLeft());
-
         shadowCursor.screenPos.setWidth(itemWidth());
         shadowCursor.screenPos.moveTopLeft(itemArea.topLeft());
     } else {
@@ -1256,6 +1516,14 @@ void HexWidget::setCursorAddr(BasicCursor addr, bool select)
     emit positionChanged(addr.address);
 
     cursor.address = addr.address;
+    // Update status bar text: current offset and function at offset
+    statusBarText = RAddressString(cursor.address);
+    {
+        QString func = Core()->cmdFunctionAt(cursor.address);
+        if (!func.isEmpty()) {
+            statusBarText += QStringLiteral(" ") + func;
+        }
+    }
 
     /* Pause cursor repainting */
     cursorEnabled = false;
@@ -1444,21 +1712,21 @@ QString HexWidget::renderItem(int offset, QColor *color)
     // FIXME: handle broken itemVal ( QVariant() )
     switch (itemFormat) {
     case ItemFormatHex:
-        item = QString("%1").arg(itemVal.toULongLong(), itemLen, 16, QLatin1Char('0'));
+        item = QStringLiteral("%1").arg(itemVal.toULongLong(), itemLen, 16, QLatin1Char('0'));
         if (itemByteLen > 1 && showExHex)
             item.prepend(hexPrefix);
         break;
     case ItemFormatOct:
-        item = QString("%1").arg(itemVal.toULongLong(), itemLen, 8, QLatin1Char('0'));
+        item = QStringLiteral("%1").arg(itemVal.toULongLong(), itemLen, 8, QLatin1Char('0'));
         break;
     case ItemFormatDec:
-        item = QString("%1").arg(itemVal.toULongLong(), itemLen, 10);
+        item = QStringLiteral("%1").arg(itemVal.toULongLong(), itemLen, 10);
         break;
     case ItemFormatSignedDec:
-        item = QString("%1").arg(itemVal.toLongLong(), itemLen, 10);
+        item = QStringLiteral("%1").arg(itemVal.toLongLong(), itemLen, 10);
         break;
     case ItemFormatFloat:
-        item = QString("%1").arg(itemVal.toDouble(), itemLen);
+        item = QStringLiteral("%1").arg(itemVal.toDouble(), itemLen);
         break;
     }
 
@@ -1473,7 +1741,7 @@ QChar HexWidget::renderAscii(int offset, QColor *color)
         *color = itemColor(byte);
     }
     if (!IS_PRINTABLE(byte)) {
-        byte = '.';
+        byte = '_';
     }
     return QChar(byte);
 }
@@ -1485,17 +1753,43 @@ QChar HexWidget::renderAscii(int offset, QColor *color)
  */
 QString HexWidget::getFlagsAndComment(uint64_t address)
 {
-    QString flagNames = Core()->listFlagsAsStringAt(address);
-    QString metaData = flagNames.isEmpty() ? "" : "Flags: " + flagNames.trimmed();
-
+    QString metaData;
+    // Gather detailed flag info: name, size, color, comment
+    // Show flag covering this address (if any)
+    RFlag *rf = Core()->core()->flags;
+    if (rf) {
+#if R2_VERSION_NUMBER >= 50909
+        RFlagItem *fi = r_flag_get_in(rf, address);
+#else
+        RFlagItem *fi = r_flag_get_i(rf, address);
+#endif
+        if (fi) {
+            // Build single entry for the flag
+            QString entry = QString::fromUtf8(fi->name);
+            entry += QString(" (size: %1").arg(fi->size);
+#if R2_VERSION_NUMBER >= 50909
+            RFlagItemMeta *fim = r_flag_get_meta(rf, fi->id);
+            if (fim && fim->color) {
+                entry += QString(", color: %1").arg(QString::fromUtf8(fim->color));
+            }
+            entry += ")";
+            if (fim && fim->comment) {
+                entry += QString(" [comment: %1]").arg(QString::fromUtf8(fim->comment).trimmed());
+            }
+#else
+            entry += ")";
+#endif
+            metaData = QStringLiteral("Flag:\n") + entry;
+        }
+    }
+    // Append general comment if present
     QString comment = Core()->getCommentAt(address);
     if (!comment.isEmpty()) {
         if (!metaData.isEmpty()) {
             metaData.append("\n");
         }
-        metaData.append("Comment: " + comment.trimmed());
+        metaData.append(QStringLiteral("Comment: %1").arg(comment.trimmed()));
     }
-
     return metaData;
 }
 
